@@ -96,33 +96,48 @@ use XAO::Web;
 ###############################################################################
 
 use vars qw($VERSION);
-$VERSION=(0+sprintf('%u.%03u',(q$Id: XAO.pm,v 2.1 2005/01/14 01:39:56 am Exp $ =~ /\s(\d+)\.(\d+)\s/))) || die "Bad VERSION";
+$VERSION=(0+sprintf('%u.%03u',(q$Id: XAO.pm,v 2.10 2008/07/30 03:47:46 am Exp $ =~ /\s(\d+)\.(\d+)\s/))) || die "Bad VERSION";
 
-use mod_perl;
-use constant MP2 => ($mod_perl::VERSION && $mod_perl::VERSION >= 1.99);
+use vars qw($MP2);
+use vars qw($HAVE_SIZE_LIMIT);
 
 BEGIN {
-    if(MP2) {
-        require Apache::Const;
-        Apache::Const->import(-compile => qw(OK DECLINED SERVER_ERROR NOT_FOUND));
-
-        ##
-        # Required to bring in methods used below
-        #
-        require Apache::Server;
-        Apache::Server->import();
-        require Apache::ServerUtil;
-        Apache::ServerUtil->import();
-        require Apache::Log;
-        Apache::Log->import();
-        require Apache::RequestRec;
-        Apache::RequestRec->import();
-        require Apache::RequestIO;
-        Apache::RequestIO->import();
+    eval {
+        require mod_perl2;
+        require Apache2::Const;
+        Apache2::Const->import(qw(:common));
+        require Apache2::ServerRec;
+        require Apache2::ServerUtil;
+        require Apache2::Log;
+        require Apache2::RequestRec;
+        require Apache2::RequestUtil;
+        require Apache2::RequestIO;
+        $MP2=2;
+    };
+    if($@) {
+        eval {
+            require Apache2;
+            require mod_perl;
+            require Apache::Const;
+            Apache::Const->import(qw(:common));
+            require Apache::Server;
+            require Apache::ServerUtil;
+            require Apache::Log;
+            require Apache::RequestRec;
+            require Apache::RequestUtil;
+            require Apache::RequestIO;
+            $MP2=1;
+        };
     }
-    else {
-        require Apache::Constants;
-        Apache::Constants->import(qw(:common));
+    if($@) {
+        eval {
+            require Apache::Constants;
+            Apache::Constants->import(qw(:common));
+            $MP2=0;
+        };
+    }
+    if($@) {
+        die "Error setting up Apache::XAO: $@";
     }
 }
 
@@ -136,7 +151,6 @@ sub server_error ($$;$);
 sub handler {
     my $r=shift;
 
-    ##
     # Request URI
     #
     my $uri=$r->uri;
@@ -146,20 +160,12 @@ sub handler {
     # Checking if we were called as a PerlHandler and complaining
     # otherwise.
     #
-    if($r->is_initial_req && exists $ENV{REQUEST_METHOD}) {
+    if($r->is_initial_req && exists $ENV{'REQUEST_METHOD'}) {
         return server_error($r,'Use PerlTransHandler',<<EOT);
 Please use 'PerlTransHandler Apache::XAO' instead of just PerlHandler.
 EOT
     }
 
-    ##
-    # By convention we disallow access to /bits/ for security reasons.
-    #
-    if(index($uri,'/bits/')>=0) {
-        ### $r->server->log_error("Attempt of direct access to /bits/ ($uri)");
-        return MP2 ? Apache::NOT_FOUND : Apache::Constants::NOT_FOUND;
-    }
-
     ##
     # Getting site name and loading the site configuration
     #
@@ -172,7 +178,13 @@ EOT
     }
     my $web=XAO::Web->new(sitename => $sitename);
 
-    ##
+    # Checking access rules
+    #
+    if(!$web->check_uri_access($uri)) {
+        $r->server->log_error("Access denied to $uri, see path_deny_table (/CVS/ and /bits/ are denied by default)");
+        return NOT_FOUND;
+    }
+
     # Checking if we need to worry about ExtFilesMap or ExtFiles in the
     # apache config.
     #
@@ -201,7 +213,6 @@ EOT
         }
     }
 
-    ##
     # Checking if we should serve this request at all. If the URI ends
     # with / we always add index.html to the URI before checking.
     #
@@ -212,13 +223,13 @@ EOT
     else {
         $pagedesc=$web->analyze($uri,$sitename,1);
     }
-    my $ptype=$pagedesc->{type} || 'xaoweb';
+    my $ptype=$pagedesc->{'type'} || 'xaoweb';
     if($ptype eq 'external') {
         ### $r->server->log_error("EXTERNAL: uri=$uri");
-        return MP2 ? Apache::DECLINED : Apache::Constants::DECLINED;
+        return DECLINED;
     }
     elsif($ptype eq 'maptodir') {
-        my $dir=$pagedesc->{directory} || '';
+        my $dir=$pagedesc->{'directory'} || '';
         if(!length($dir) || substr($dir,0,1) ne '/') {
             my $phdir=$XAO::Base::projectsdir . "/" . $sitename;
             if(length($dir)) {
@@ -232,17 +243,15 @@ EOT
         $dir=~s/\/{2,}/\//g;
         $r->filename($dir);
         ### $r->server->log_error("MAPTODIR: => $dir");
-        return MP2 ? Apache::OK : Apache::Constants::OK;
+        return OK;
     }
 
-    ##
     # We pass the knowledge along in the 'notes' table.
     #
     $r->pnotes(xaoweb   => $web);
     $r->pnotes(pagedesc => $pagedesc);
     $r->pnotes(uri      => $uri);
 
-    ##
     # Default is to install a content handler to produce actual output.
     # It could be more optimal to have two always present handlers
     # instead of pushing/popping automatically -- in this case
@@ -256,25 +265,24 @@ EOT
     if($htype eq 'auto') {
         ### $r->server->log_error("TRANS: auto (uri=$uri)");
 
-        ##
         # In mod_perl 2.x filepath translation is done in a separate
         # phase, we need to set up a handler for it -- otherwise apache
         # will still attempt to map filename, and worse yet -- attempt
         # to redirect to language specific 'index.html.en' for example.
         #
-        if(MP2) {
+        if($MP2) {
             $r->push_handlers(PerlMapToStorageHandler => \&handler_map_to_storage);
             $r->push_handlers(PerlResponseHandler => \&handler_content);
-            return Apache::OK();
+            return OK;
         }
         else {
             $r->push_handlers(PerlHandler => \&handler_content);
-            return Apache::Constants::OK();
+            return OK;
         }
     }
     elsif($htype eq 'static') {
         ### $r->server->log_error("TRANS: static (uri=$uri)");
-        return MP2 ? Apache::OK : Apache::Constants::OK;
+        return OK;
     }
     else {
         return server_error($r,"Unknown HandlerType '$htype'");
@@ -286,21 +294,50 @@ EOT
 sub handler_content ($) {
     my $r=shift;
 
-    ##
     # Getting the data. If there is no data then trans handler was not
     # executed or has declined, so we do not need to do anything.
     #
     my $web=$r->pnotes('xaoweb') ||
-        return MP2 ? Apache::DECLINED : Apache::Constants::DECLINED;
+        return DECLINED;
     my $pagedesc=$r->pnotes('pagedesc');
 
-    ##
+    # If needed setting up SizeLimit to possibly restart this process
+    # when it gets too big. Controlled by memory_size_limit parameters
+    # in the site config:
+    #
+    #  check_every_n_requests | every_n_requests
+    #  max_process_size         (in KB)
+    #  min_share_size           (in KB)
+    #  max_unshared_size        (in KB)
+    #
+    if(my $msl=$web->config->get('memory_size_limit')) {
+        if($MP2 && $MP2==2) {
+            if(!$HAVE_SIZE_LIMIT) {
+                require Apache2::MPM;
+                require Apache2::SizeLimit;
+                $HAVE_SIZE_LIMIT=1;
+            }
+
+            $Apache2::SizeLimit::CHECK_EVERY_N_REQUESTS=$msl->{'check_every_n_requests'} if $msl->{'check_every_n_requests'};
+            $Apache2::SizeLimit::CHECK_EVERY_N_REQUESTS=$msl->{'every_n_requests'} if $msl->{'every_n_requests'};
+
+            Apache2::SizeLimit::setmin($msl->{'min_share_size'}) if $msl->{'min_share_size'};
+            Apache2::SizeLimit::setmin($msl->{'min_shared_size'}) if $msl->{'min_shared_size'};
+            Apache2::SizeLimit::setmax($msl->{'max_process_size'},$r) if $msl->{'max_process_size'};
+            Apache2::SizeLimit::setmax_unshared($msl->{'max_unshared_size'}) if $msl->{'max_unshared_size'};
+
+            ### $r->server->log_error("$Apache2::SizeLimit::CHECK_EVERY_N_REQUESTS / $Apache2::SizeLimit::MIN_SHARE_SIZE / $Apache2::SizeLimit::MAX_UNSHARED_SIZE / $Apache2::SizeLimit::MAX_PROCESS_SIZE");
+        }
+        else {
+            $r->server->log_error("memory_size_limit is only supported when Apache2::SizeLimit is available");
+        }
+    }
+
     # We have to get the original URI, the one in $r->uri may get mangled
     #
     my $uri=$r->pnotes('uri');
     ### $r->server->log_error("CONTENT: uri=$uri");
 
-    ##
     # Executing
     #
     $web->execute(
@@ -309,7 +346,7 @@ sub handler_content ($) {
         pagedesc    => $pagedesc,
     );
 
-    return MP2 ? Apache::OK : Apache::Constants::OK;
+    return OK;
 }
 
 ###############################################################################
@@ -317,7 +354,7 @@ sub handler_content ($) {
 sub handler_map_to_storage {
     my $r=shift;
     ### $r->server->log_error("MAPTOSTORAGE: uri=".$r->uri);
-    return Apache::OK();
+    return OK;
 }
 
 ###############################################################################
@@ -329,10 +366,10 @@ sub server_error ($$;$) {
 
     $r->server->log_error("*ERROR: Apache::XAO - $name");
     $r->custom_response(
-        (MP2 ? Apache::SERVER_ERROR : Apache::Constants::SERVER_ERROR),
+        SERVER_ERROR,
         "<H2>XAO::Web System Error: $name</H2>\n$desc"
     );
-    return MP2 ? Apache::SERVER_ERROR : Apache::Constants::SERVER_ERROR;
+    return SERVER_ERROR;
 }
 
 ###############################################################################
