@@ -85,12 +85,12 @@ L<XAO::DO::Web::Page>.
 ###############################################################################
 package XAO::DO::Web::Header;
 use strict;
-use XAO::Utils;
+use XAO::Utils qw(:args :debug :html);
 use XAO::Objects;
 use base XAO::Objects->load(objname => 'Web::Page');
 
 use vars qw($VERSION);
-$VERSION=(0+sprintf('%u.%03u',(q$Id: Header.pm,v 2.1 2005/01/14 01:39:57 am Exp $ =~ /\s(\d+)\.(\d+)\s/))) || die "Bad VERSION";
+$VERSION=(0+sprintf('%u.%03u',(q$Id: Header.pm,v 2.4 2005/12/27 04:10:22 am Exp $ =~ /\s(\d+)\.(\d+)\s/))) || die "Bad VERSION";
 
 ###############################################################################
 # Displaying HTML header.
@@ -99,7 +99,7 @@ sub display ($;%) {
     my $self=shift;
     my $args=get_args(\@_);
 
-    if($args->{type}) {
+    if($args->{'type'}) {
         $self->siteconfig->header_args(-type => $args->{type});
         return;
     }
@@ -111,16 +111,24 @@ sub display ($;%) {
         return;
     }
 
-    my $meta="";
-    $meta.=qq(<META NAME="Keywords" CONTENT="$args->{keywords}">\n) if $args->{keywords};
-    $meta.=qq(<META NAME="Description" CONTENT="$args->{description}">\n) if $args->{description};
+    my $meta='';
+    $meta.=qq(<META NAME="Keywords" CONTENT=").t2hf($args->{'keywords'}).qq(">\n)
+        if $args->{'keywords'};
+    $meta.=qq(<META NAME="Description" CONTENT=").t2hf($args->{'description'}).qq(">\n)
+        if $args->{'description'};
 
-    $self->SUPER::display(merge_refs($args, {
-                            path        => $args->{path} || "/bits/page-header",
-                            TITLE       => $args->{title} || "XAO::Web -- No Title",
-                            GIVEN_TITLE => $args->{title} || '',
-                            META        => $meta,
-                         }));
+    my $title=$args->{'title'} ||
+              $self->siteconfig->get('default_title') ||
+              "XAO::Web -- No Title";
+
+    $self->object->display($args,{
+        path        => $args->{'path'} || "/bits/page-header",
+        TITLE       => $title,
+        GIVEN_TITLE => $args->{'title'} || '',
+        META        => $meta,
+        KEYWORDS    => $args->{'keywords'},
+        DESCRIPTION => $args->{'description'},
+    });
 }
 
 ###############################################################################
