@@ -22,6 +22,8 @@ performed:
  <%URL base top secure%>    -- https://host.com
  <%URL base full secure%>   -- https://host.com/test.html
  <%URL secure%>             -- https://www.host.com/test.html
+ <%URL uri%>                -- /test.html
+ <%URL x='TAG'%>            -- from /extra_urls, assumes "top"
 
 If browser is at 'https://www.host.com/test.html' (secure protocol):
 
@@ -33,14 +35,16 @@ If browser is at 'https://www.host.com/test.html' (secure protocol):
 =head1 DESCRIPTION
 
 Allows to display URL with some possible alterations. Default is to
-display full URL of the current page using active host name, if the page
-is a secure one then the URL will be secure. Active host name is usually
-the same as base host name, but may differ if your web server is set up
-to serve more then one domain using the same XAO::Web site.
+display full URL of the current page using the base host name. If the
+page is a secure one then the URL will also be secure.
 
 Base URL is set as 'base_url' parameter in the initial site
 configuration.
 
+Active host name is usually the same as base host name, but may differ
+if your web server is set up to serve more then one domain using the
+same XAO::Web site.
+
 =head1 METHODS
 
 =over
@@ -55,28 +59,52 @@ use XAO::Objects;
 use base XAO::Objects->load(objname => 'Web::Page');
 
 use vars qw($VERSION);
-$VERSION=(0+sprintf('%u.%03u',(q$Id: URL.pm,v 2.1 2005/01/14 01:39:57 am Exp $ =~ /\s(\d+)\.(\d+)\s/))) || die "Bad VERSION";
+$VERSION=(0+sprintf('%u.%03u',(q$Id: URL.pm,v 2.2 2007/01/29 05:22:13 am Exp $ =~ /\s(\d+)\.(\d+)\s/))) || die "Bad VERSION";
 
 sub display ($%) {
     my $self=shift;
     my $args=get_args(\@_);
 
-    my $active=$args->{base} ? 0 : 1;
-    my $full=$args->{top} ? 0 : 1;
-
     my $secure;
-    if($args->{secure}) {
+    if($args->{'secure'}) {
         $secure=1;
     }
-    elsif($args->{insecure}) {
+    elsif($args->{'insecure'}) {
         $secure=0;
     }
     else {
         $secure=$self->is_secure;
     }
 
-    my $url=$full ? $self->pageurl(active => $active, secure => $secure) :
-                    $self->base_url(active => $active, secure => $secure);
+    my $url;
+
+    my $x=$args->{'x'};
+
+    if($x) {
+        my $extra_urls=$self->siteconfig->get('extra_urls') || { };
+
+        $url=$extra_urls->{$x.'.'.($secure ? 'secure' : 'insecure')};
+
+        if(!$url) {
+            $url=$extra_urls->{$x} ||
+                 $self->base_url(active => 0, secure => $secure);
+
+            if($secure) {
+                $url=~s/^http:/https:/;
+            }
+        }
+    }
+    else {
+        my $active=$args->{'active'} ? 1 : 0;
+        my $full=$args->{'top'} ? 0 : 1;
+
+        $url=$full ? $self->pageurl(active => $active, secure => $secure) :
+                     $self->base_url(active => $active, secure => $secure);
+    }
+
+    if($args->{'uri'}) {
+        $url=~s/^\w+:\/\/.*?\//\//;
+    }
 
     $self->textout($url);
 }
