@@ -34,7 +34,7 @@ use XAO::Objects;
 use base XAO::Objects->load(objname => 'Web::Action');
 
 use vars qw($VERSION);
-$VERSION=(0+sprintf('%u.%03u',(q$Id: Utility.pm,v 2.1 2005/01/14 01:39:57 am Exp $ =~ /\s(\d+)\.(\d+)\s/))) || die "Bad VERSION";
+$VERSION=(0+sprintf('%u.%03u',(q$Id: Utility.pm,v 2.3 2006/03/07 18:14:54 am Exp $ =~ /\s(\d+)\.(\d+)\s/))) || die "Bad VERSION";
 
 sub check_mode ($$) {
     my $self=shift;
@@ -101,42 +101,40 @@ Would display:
 
 =cut
 
-sub tracking_url ($%)
-{ my $self=shift;
-  my $args=get_args(\@_);
-  my $carrier=$args->{carrier};
-  my $tracknum=$args->{tracknum};
-  my $url;
-  if(lc($carrier) eq 'usps')
-   { $url='http://www.framed.usps.com/cgi-bin/cttgate/ontrack.cgi' .
-          '?tracknbr=' . t2ht($tracknum);
-   }
-  elsif(lc($carrier) eq 'ups')
-   { $url='http://wwwapps.ups.com/WebTracking/processInputRequest' .
-          '?HTMLVersion=5.0&sort_by=status&tracknums_displayed=1' .
-          '&TypeOfInquiryNumber=T&loc=en_US&AgreeToTermsAndConditions=yes' .
-          '&InquiryNumber1=' . t2ht($tracknum);
-   }
-  elsif(lc($carrier) eq 'fedex')
-   { $url='http://fedex.com/cgi-bin/tracking' .
-          '?tracknumbers=' .  t2ht($tracknum) .
-          '&action=track&language=english&cntry_code=us';
-   }
-  elsif(lc($carrier) eq 'dhl')
-   { $url='http://www.dhl-usa.com/cgi-bin/tracking.pl' .
-          '?AWB=' . t2ht($tracknum) .
-          'LAN=ENG&TID=US_ENG&FIRST_DB=US';
-   }
-  elsif(lc($carrier) eq 'yellow')
-   { $tracknum=sprintf('%09u',int($tracknum));
-     $url='http://www2.yellowcorp.com/cgi-bin/gx.cgi/applogic+yfsgentracing.E000YfsTrace' .
-          '?diff=protrace&PRONumber=' . t2ht($tracknum);
-   }
-  else
-   { eprint "Unknown carrier '$carrier'";
-     $url='';
-   }
-  $self->textout($url);
+sub tracking_url ($%) {
+    my $self=shift;
+    my $args=get_args(\@_);
+
+    my $carrier=$args->{'carrier'} || '';
+    my $tracknum=$args->{tracknum} || '';
+
+    my $url;
+
+    if(lc($carrier) eq 'usps') {
+        $url='https://tools.usps.com/go/TrackConfirmAction.action?tRef=fullpage&tLc=1&tLabels=' . t2hq($tracknum);
+    }
+    elsif(lc($carrier) eq 'ups') {
+        $url='http://wwwapps.ups.com/etracking/tracking.cgi?tracknum=' . t2hq($tracknum);
+    }
+    elsif(lc($carrier) eq 'fedex') {
+        $url='https://www.fedex.com/apps/fedextrack/?action=track&tracknumbers=' . t2hq($tracknum);
+    }
+    elsif(lc($carrier) eq 'dhl') {
+        $url='http://www.dhl-usa.com/cgi-bin/tracking.pl' .
+             '?AWB=' . t2hq($tracknum) .
+             'LAN=ENG&TID=US_ENG&FIRST_DB=US';
+    }
+    elsif(lc($carrier) eq 'yellow') {
+        $tracknum=sprintf('%09u',int($tracknum));
+        $url='http://www2.yellowcorp.com/cgi-bin/gx.cgi/applogic+yfsgentracing.E000YfsTrace' .
+             '?diff=protrace&PRONumber=' . t2hq($tracknum);
+    }
+    else {
+        eprint "Unknown carrier '$carrier'";
+        $url='';
+    }
+
+    $self->textout($url);
 }
 
 ###############################################################################
@@ -195,7 +193,7 @@ Would produce:
 Actual output would be slightly different because no carriage return
 symbol would be inserted between hidden <INPUT> tags. This is done for
 rare situations when your code is space sensitive and you do not want to
-mess it.
+mess it up.
 
 Query example:
 
@@ -211,6 +209,11 @@ the output would be:
 
  <A HREF="report.html?sortby=price&sku=123&category=234">Sort by price</A>
 
+For 'query' results it is convenient to also provide a 'prefix'
+parameter that would be included in the output only if there are
+parameters to copy. This allows to cleanly format URLs without extra '?'
+or '&' symbols.
+
 All special symbols in parameter values would be properly escaped, you
 do not need to worry about that.
 
@@ -220,7 +223,6 @@ sub pass_cgi_params ($%) {
     my $self=shift;
     my $args=get_args(\@_);
 
-    ##
     # Creating list of exceptions
     #
     my %except;
@@ -238,7 +240,6 @@ sub pass_cgi_params ($%) {
         $except{$param}=1;
     }
 
-    ##
     # Expanding parameters in list
     #
     my @params;
@@ -257,7 +258,6 @@ sub pass_cgi_params ($%) {
         push @params,$param;
     }
 
-    ##
     # Creating HTML code that will pass these parameters.
     #
     my $html;
@@ -277,7 +277,12 @@ sub pass_cgi_params ($%) {
         }
     }
 
-    $self->textout($html) if defined $html;
+    # No output if there are no parameters
+    #
+    if(defined $html) {
+        $self->textout($args->{'prefix'}) if $args->{'prefix'};
+        $self->textout($html);
+    }
 }
 
 ###############################################################################
