@@ -24,7 +24,7 @@ use XAO::Utils;
 use XAO::Projects qw(get_current_project_name);
 
 use vars qw($VERSION);
-($VERSION)=('$Id: Templates.pm,v 1.7 2003/10/29 01:12:49 am Exp $' =~ /(\d+\.\d+)/);
+$VERSION=(0+sprintf('%u.%03u',(q$Id: Templates.pm,v 2.1 2005/01/14 01:39:56 am Exp $ =~ /\s(\d+)\.(\d+)\s/))) || die "Bad VERSION";
 
 ##
 # Cache for templates.
@@ -190,6 +190,8 @@ __END__
 
 =head1 AUTHOR
 
-Copyright (c) 2000-2003 XAO Inc.
+Copyright (c) 2005 Andrew Maltsev
 
-The author is Andrew Maltsev <am@xao.com>
+Copyright (c) 2001-2004 Andrew Maltsev, XAO Inc.
+
+<am@ejelta.com> -- http://ejelta.com/xao/
